{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-primary-analysis/harmonization_with_bwa:1.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "FASTQ file for input read (read R1 in Paired End mode)",
                    "id": "#bwa_mem_only.cwl/input_read1_fastq_file"
                },
                {
                    "type": "File",
                    "doc": "FASTQ file for read R2 in Paired End mode, if there is one.",
                    "id": "#bwa_mem_only.cwl/input_read2_fastq_file"
                },
                {
                    "type": "string",
                    "id": "#bwa_mem_only.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "doc": "Specifies the readgroup. (e.g. \"@RG\\tCN:\\tPL:\\tID:\\tSM:\\tPU:\\tLB:\")",
                    "id": "#bwa_mem_only.cwl/readgroup_line"
                },
                {
                    "type": "string",
                    "doc": "Name of the output file.",
                    "id": "#bwa_mem_only.cwl/readgroup_name"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#bwa_mem_only.cwl/reference"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.BWA_mem_' + inputs.readgroup_name + '.time.json') /opt/bwa-0.7.17/bwa mem -K 100000000 -M -v 3 -t 30 -Y $(inputs.reference.path) -R '$(inputs.readgroup_line)' $(inputs.input_read1_fastq_file.path) $(inputs.input_read2_fastq_file.path) | /opt/sambamba-0.6.8-linux-static view -t 30 -f bam -S /dev/stdin | /opt/sambamba-0.6.8-linux-static sort -t 30 --natural-sort -m 15GiB --tmpdir ./ -o $(inputs.readgroup_name).unsorted.bam -l 5 /dev/stdin"
                }
            ],
            "id": "#bwa_mem_only.cwl",
            "outputs": [
                {
                    "type": "File",
                    "doc": "BWA BAM output file.",
                    "outputBinding": {
                        "glob": "*bam"
                    },
                    "id": "#bwa_mem_only.cwl/readgroup_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.BWA_mem_' + inputs.readgroup_name + '.time.json')"
                    },
                    "id": "#bwa_mem_only.cwl/time_metrics"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-primary-analysis/harmonization_with_bwa:1.0"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#markduplicates_on_bam.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#markduplicates_on_bam.cwl/job_uuid"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.mrkdup.bam')"
                    },
                    "id": "#markduplicates_on_bam.cwl/mrkdup_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.SamtoolsFilter_SamblasterMrkdup' + '.time.json')"
                    },
                    "id": "#markduplicates_on_bam.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.SamtoolsFilter_SamblasterMrkdup' + '.time.json') samtools view -@ 32 -Sh -f 3 $(inputs.bam.path) | /opt/samblaster-v.0.1.24/samblaster -M -i /dev/stdin -o /dev/stdout | /opt/sambamba-0.6.8-linux-static view -t 30 -f bam -S -o $(inputs.job_uuid).mrkdup.bam /dev/stdin"
                }
            ],
            "id": "#markduplicates_on_bam.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-primary-analysis/harmonization_with_bwa:1.0"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "inputBinding": {
                        "position": 1,
                        "shellQuote": false
                    },
                    "id": "#sambamba_merge.cwl/bams"
                },
                {
                    "type": "string",
                    "id": "#sambamba_merge.cwl/base_file_name"
                },
                {
                    "type": "string",
                    "id": "#sambamba_merge.cwl/job_uuid"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam",
                        "outputEval": "${\n    if(inputs.bams.length > 1) return self\n    else return inputs.bams\n}"
                    },
                    "id": "#sambamba_merge.cwl/merged_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.SambambaMerge' + '.time.json')"
                    },
                    "id": "#sambamba_merge.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "${\n    var time_cmd = \"/usr/bin/time -f \\\"{\\\\\\\"real_time\\\\\\\": \\\\\\\"%E\\\\\\\", \\\\\\\"user_time\\\\\\\": %U, \\\\\\\"system_time\\\\\\\": %S, \\\\\\\"wall_clock\\\\\\\": %e, \\\\\\\"maximum_resident_set_size\\\\\\\": %M, \\\\\\\"average_total_mem\\\\\\\": %K, \\\\\\\"percent_of_cpu\\\\\\\": \\\\\\\"%P\\\\\\\"}\\\" -o \" + inputs.job_uuid + \".SambambaMerge\" + \".time.json\"\n    if (inputs.bams.length != 1)\n     return time_cmd + \" /opt/sambamba-0.6.8-linux-static merge -t 32 \" + inputs.base_file_name + \".aligned.duplicates_marked.unsorted.bam\"\n    else return time_cmd + \" ls\"\n }"
                }
            ],
            "id": "#sambamba_merge.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-primary-analysis/harmonization_with_bwa:1.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#sambamba_sort.cwl/bam"
                },
                {
                    "type": "string",
                    "id": "#sambamba_sort.cwl/base_file_name"
                },
                {
                    "type": "string",
                    "id": "#sambamba_sort.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "default": "aligned.duplicates_marked.sorted",
                    "id": "#sambamba_sort.cwl/suffix"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "secondaryFiles": [
                        "^.bai"
                    ],
                    "format": "#sambamba_sort.cwl/BAM",
                    "id": "#sambamba_sort.cwl/sorted_bam"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.SambambaSort' + '.time.json')"
                    },
                    "id": "#sambamba_sort.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.SambambaSort' + '.time.json') /opt/sambamba-0.6.8-linux-static sort -t 32 -m 100G -o $(inputs.base_file_name).$(inputs.suffix).bam $(inputs.bam.path) && mv $(inputs.base_file_name).$(inputs.suffix).bam.bai $(inputs.base_file_name).$(inputs.suffix).bai"
                }
            ],
            "id": "#sambamba_sort.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "registry.gitlab.com/uc-cdis/genomel-primary-analysis/harmonization_with_bwa:1.0"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "FASTQ file for input read1.",
                    "id": "#trimmomatic.cwl/input_read1_fastq_file"
                },
                {
                    "type": "File",
                    "doc": "FASTQ file for read R2 in Paired End mode.",
                    "id": "#trimmomatic.cwl/input_read2_fastq_file"
                },
                {
                    "type": "string",
                    "id": "#trimmomatic.cwl/job_uuid"
                },
                {
                    "type": "string",
                    "id": "#trimmomatic.cwl/readgroup_line"
                },
                {
                    "type": "string",
                    "id": "#trimmomatic.cwl/readgroup_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_read1_fastq_file.nameroot.replace(/\\.[^/.]+$/, \"\") + '.trimmed.fastq.gz')"
                    },
                    "id": "#trimmomatic.cwl/output_read1_trimmed_file"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_read2_fastq_file.nameroot.replace(/\\.[^/.]+$/, \"\") + '.trimmed.fastq.gz')"
                    },
                    "id": "#trimmomatic.cwl/output_read2_trimmed_file"
                },
                {
                    "type": "string",
                    "outputBinding": {
                        "outputEval": "${ return inputs.readgroup_line }\n"
                    },
                    "id": "#trimmomatic.cwl/paired_readgroup_line"
                },
                {
                    "type": "string",
                    "outputBinding": {
                        "outputEval": "${ return inputs.readgroup_name }\n"
                    },
                    "id": "#trimmomatic.cwl/paired_readgroup_name"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.job_uuid + '.trimmomatic.' + inputs.readgroup_name + '.time.json')"
                    },
                    "id": "#trimmomatic.cwl/time_metrics"
                }
            ],
            "baseCommand": [],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "/usr/bin/time -f \"{\\\\\"real_time\\\\\": \\\\\"%E\\\\\", \\\\\"user_time\\\\\": %U, \\\\\"system_time\\\\\": %S, \\\\\"wall_clock\\\\\": %e, \\\\\"maximum_resident_set_size\\\\\": %M, \\\\\"average_total_mem\\\\\": %K, \\\\\"percent_of_cpu\\\\\": \\\\\"%P\\\\\"}\" -o $(inputs.job_uuid + '.trimmomatic.' + inputs.readgroup_name + '.time.json') java -Xmx32g -jar /opt/Trimmomatic-0.38/trimmomatic-0.38.jar PE -threads 24 -phred33 $(inputs.input_read1_fastq_file.path) $(inputs.input_read2_fastq_file.path) $(inputs.input_read1_fastq_file.nameroot.replace(/\\.[^/.]+$/, \"\") + '.trimmed.fastq.gz') $(inputs.input_read1_fastq_file.nameroot.replace(/\\.[^/.]+$/, \"\") + '.trimmed.unpaired.fastq.gz') $(inputs.input_read2_fastq_file.nameroot.replace(/\\.[^/.]+$/, \"\") + '.trimmed.fastq.gz') $(inputs.input_read2_fastq_file.nameroot.replace(/\\.[^/.]+$/, \"\") + '.trimmed.unpaired.fastq.gz') ILLUMINACLIP:/opt/Trimmomatic-0.38/adapters/TruSeq3-PE-2.fa:2:30:12 LEADING:12 TRAILING:12 SLIDINGWINDOW:4:15 MINLEN:36"
                }
            ],
            "id": "#trimmomatic.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_read1"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/input_read2"
                },
                {
                    "type": "string",
                    "id": "#main/job_uuid"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/readgroup_lines"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "id": "#main/readgroup_names"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".fai",
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        "^.dict",
                        ".amb",
                        ".ann",
                        ".bwt",
                        ".pac",
                        ".sa"
                    ],
                    "id": "#main/reference"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bam_sort/sorted_bam",
                    "id": "#main/sorted_bam"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bwa_mem/time_metrics",
                    "id": "#main/time_metrics_from_bwa_mem"
                },
                {
                    "type": "File",
                    "outputSource": "#main/readgroups_merge/time_metrics",
                    "id": "#main/time_metrics_from_merge"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bam_mrkdup/time_metrics",
                    "id": "#main/time_metrics_from_mrkdup"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bam_sort/time_metrics",
                    "id": "#main/time_metrics_from_sort"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/trim_adaptor/time_metrics",
                    "id": "#main/time_metrics_from_trim_adaptor"
                }
            ],
            "steps": [
                {
                    "run": "#markduplicates_on_bam.cwl",
                    "in": [
                        {
                            "source": "#main/readgroups_merge/merged_bam",
                            "id": "#main/bam_mrkdup/bam"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/bam_mrkdup/job_uuid"
                        }
                    ],
                    "out": [
                        "#main/bam_mrkdup/mrkdup_bam",
                        "#main/bam_mrkdup/time_metrics"
                    ],
                    "id": "#main/bam_mrkdup"
                },
                {
                    "run": "#sambamba_sort.cwl",
                    "in": [
                        {
                            "source": "#main/bam_mrkdup/mrkdup_bam",
                            "id": "#main/bam_sort/bam"
                        },
                        {
                            "source": "#main/job_uuid",
                            "valueFrom": "$(self)",
                            "id": "#main/bam_sort/base_file_name"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/bam_sort/job_uuid"
                        }
                    ],
                    "out": [
                        "#main/bam_sort/sorted_bam",
                        "#main/bam_sort/time_metrics"
                    ],
                    "id": "#main/bam_sort"
                },
                {
                    "run": "#bwa_mem_only.cwl",
                    "scatter": [
                        "#main/bwa_mem/input_read1_fastq_file",
                        "#main/bwa_mem/input_read2_fastq_file",
                        "#main/bwa_mem/readgroup_line",
                        "#main/bwa_mem/readgroup_name"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/trim_adaptor/output_read1_trimmed_file",
                            "id": "#main/bwa_mem/input_read1_fastq_file"
                        },
                        {
                            "source": "#main/trim_adaptor/output_read2_trimmed_file",
                            "id": "#main/bwa_mem/input_read2_fastq_file"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/bwa_mem/job_uuid"
                        },
                        {
                            "source": "#main/trim_adaptor/paired_readgroup_line",
                            "id": "#main/bwa_mem/readgroup_line"
                        },
                        {
                            "source": "#main/trim_adaptor/paired_readgroup_name",
                            "id": "#main/bwa_mem/readgroup_name"
                        },
                        {
                            "source": "#main/reference",
                            "id": "#main/bwa_mem/reference"
                        }
                    ],
                    "out": [
                        "#main/bwa_mem/readgroup_bam",
                        "#main/bwa_mem/time_metrics"
                    ],
                    "id": "#main/bwa_mem"
                },
                {
                    "run": "#sambamba_merge.cwl",
                    "in": [
                        {
                            "source": "#main/bwa_mem/readgroup_bam",
                            "id": "#main/readgroups_merge/bams"
                        },
                        {
                            "source": "#main/job_uuid",
                            "valueFrom": "$(self)",
                            "id": "#main/readgroups_merge/base_file_name"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/readgroups_merge/job_uuid"
                        }
                    ],
                    "out": [
                        "#main/readgroups_merge/merged_bam",
                        "#main/readgroups_merge/time_metrics"
                    ],
                    "id": "#main/readgroups_merge"
                },
                {
                    "run": "#trimmomatic.cwl",
                    "scatter": [
                        "#main/trim_adaptor/readgroup_line",
                        "#main/trim_adaptor/readgroup_name",
                        "#main/trim_adaptor/input_read1_fastq_file",
                        "#main/trim_adaptor/input_read2_fastq_file"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/input_read1",
                            "id": "#main/trim_adaptor/input_read1_fastq_file"
                        },
                        {
                            "source": "#main/input_read2",
                            "id": "#main/trim_adaptor/input_read2_fastq_file"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/trim_adaptor/job_uuid"
                        },
                        {
                            "source": "#main/readgroup_lines",
                            "id": "#main/trim_adaptor/readgroup_line"
                        },
                        {
                            "source": "#main/readgroup_names",
                            "id": "#main/trim_adaptor/readgroup_name"
                        }
                    ],
                    "out": [
                        "#main/trim_adaptor/paired_readgroup_line",
                        "#main/trim_adaptor/paired_readgroup_name",
                        "#main/trim_adaptor/output_read1_trimmed_file",
                        "#main/trim_adaptor/output_read2_trimmed_file",
                        "#main/trim_adaptor/time_metrics"
                    ],
                    "id": "#main/trim_adaptor"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
